Header

Struct Header 

#[repr(transparent)]
pub struct Header(pub u16);
Definition of the message header. Every message shall start with it.

Tuple Fields

0: u16

Implementations

Source

impl Header

pub fn extended(&self) -> bool

Shall be set to zero to indicate a Control Message or Data Message and set to one to indicate an Extended Message.

pub fn with_extended(self, value: bool) -> Self

Shall be set to zero to indicate a Control Message or Data Message and set to one to indicate an Extended Message.

pub fn set_extended(&mut self, value: bool)

Shall be set to zero to indicate a Control Message or Data Message and set to one to indicate an Extended Message.

pub fn num_objects(&self) -> usize

The number of 32 bit data objects that follow the header.

pub fn with_num_objects(self, value: u8) -> Self

The number of 32 bit data objects that follow the header.

pub fn set_num_objects(&mut self, value: u8)

The number of 32 bit data objects that follow the header.

pub fn message_id(&self) -> u8

A rolling counter, maintained by the originator of the message.

pub fn with_message_id(self, value: u8) -> Self

A rolling counter, maintained by the originator of the message.

pub fn set_message_id(&mut self, value: u8)

A rolling counter, maintained by the originator of the message.

pub fn port_power_role(&self) -> PowerRole

Indicate the port’s present power role (0 -> sink, 1 -> source).

pub fn with_port_power_role(self, value: PowerRole) -> Self

Indicate the port’s present power role (0 -> sink, 1 -> source).

pub fn set_port_power_role(&mut self, value: PowerRole)

Indicate the port’s present power role (0 -> sink, 1 -> source).

pub fn spec_revision( &self, ) -> Result<SpecificationRevision, <SpecificationRevision as TryFrom<u8>>::Error>

The specification revision.

00b - Revision 1.0 (deprecated) 01b - Revision 2.0 10b - Revision 3.x 11b - Reserved, shall not be used

pub fn with_spec_revision(self, value: SpecificationRevision) -> Self

The specification revision.

00b - Revision 1.0 (deprecated) 01b - Revision 2.0 10b - Revision 3.x 11b - Reserved, shall not be used

pub fn set_spec_revision(&mut self, value: SpecificationRevision)

The specification revision.

00b - Revision 1.0 (deprecated) 01b - Revision 2.0 10b - Revision 3.x 11b - Reserved, shall not be used

pub fn port_data_role(&self) -> DataRole

The port’s data role (0 -> UFP, 1 -> DFP).

pub fn with_port_data_role(self, value: DataRole) -> Self

The port’s data role (0 -> UFP, 1 -> DFP).

pub fn set_port_data_role(&mut self, value: DataRole)

The port’s data role (0 -> UFP, 1 -> DFP).

pub fn message_type_raw(&self) -> u8

The type of message being sent. See [6.2.1.1.8] for details

pub fn with_message_type_raw(self, value: u8) -> Self

The type of message being sent. See [6.2.1.1.8] for details

pub fn set_message_type_raw(&mut self, value: u8)

The type of message being sent. See [6.2.1.1.8] for details

Source

impl Header

pub fn new_template( port_data_role: DataRole, port_power_role: PowerRole, spec_revision: SpecificationRevision, ) -> Self

Create a header template with the given attributes.

pub fn new( template: Self, message_id: Counter, message_type: MessageType, num_objects: u8, extended: bool, ) -> Self

Create a new header that follows a template.

pub fn new_control( template: Self, message_id: Counter, message_type: ControlMessageType, ) -> Self

Create a new control message header.

pub fn new_data( template: Self, message_id: Counter, message_type: DataMessageType, num_objects: u8, ) -> Self

Create a new data message header.

pub fn new_extended( template: Self, message_id: Counter, extended_message_type: ExtendedMessageType, num_objects: u8, ) -> Self

Create a new extended message header.

pub fn from_bytes(buf: &[u8]) -> Result<Self, ParseError>

Parse a header from its binary representation.

pub fn to_bytes(self, buf: &mut [u8]) -> usize

Serialize the header to its binary representation.

pub fn message_type(&self) -> MessageType

Extract the message type that the header encodes.